@@ -1,10 +1,8 @@
-import eventlet
-requests = eventlet.import_patched('requests')
+import requests
 from deezer.gw import GW
 from deezer.api import API
-import json
 
-__version__ = "0.0.15"
+__version__ = "1.0.3"
 
 class TrackFormats():
     """Number associtation for formats"""
@@ -18,15 +16,13 @@ class TrackFormats():
     LOCAL   = 0
 
 class Deezer:
-    def __init__(self):
+    def __init__(self, accept_language=None):
         self.http_headers = {
             "User-Agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) " \
                           "Chrome/79.0.3945.130 Safari/537.36",
-            "Accept-Language": None
+            "Accept-Language": accept_language
         }
         self.session = requests.Session()
-        self.session.mount('http://', requests.adapters.HTTPAdapter(pool_maxsize=100))
-        self.session.mount('https://', requests.adapters.HTTPAdapter(pool_maxsize=100))
 
         self.logged_in = False
         self.current_user = {}
@@ -36,11 +32,28 @@ class Deezer:
         self.api = API(self.session, self.http_headers)
         self.gw = GW(self.session, self.http_headers)
 
+    def get_accept_language(self):
+        return self.http_headers['Accept-Language']
+
     def set_accept_language(self, lang):
         self.http_headers['Accept-Language'] = lang
 
-    def get_accept_language(self):
-        return self.http_headers['Accept-Language']
+    def get_session(self):
+        return {
+            'logged_in': self.logged_in,
+            'current_user': self.current_user,
+            'childs': self.childs,
+            'selected_account': self.selected_account,
+            'cookies': self.session.cookies.get_dict()
+        }
+
+    def set_session(self, data):
+        self.logged_in = data['logged_in']
+        self.current_user = data['current_user']
+        self.childs = data['childs']
+        self.selected_account = data['selected_account']
+        self.session = requests.Session()
+        self.session.cookies.update(data['cookies'])
 
     def login(self, email, password, re_captcha_token, child=0):
         # Check if user already logged in
@@ -100,20 +113,57 @@ class Deezer:
                 self.childs.append({
                     'id': child["USER_ID"],
                     'name': child["BLOG_NAME"],
-                    'picture': child.get("USER_PICTURE", "")
+                    'picture': child.get("USER_PICTURE", ""),
+                    'license_token': child["OPTIONS"]["license_token"],
+                    'can_stream_hq': child["OPTIONS"]["web_hq"] or child["OPTIONS"]["mobile_hq"],
+                    'can_stream_lossless': child["OPTIONS"]["web_lossless"] or child["OPTIONS"]["mobile_lossless"]
                 })
         else:
             self.childs.append({
                 'id': user_data["USER"]["USER_ID"],
                 'name': user_data["USER"]["BLOG_NAME"],
-                'picture': user_data["USER"].get("USER_PICTURE", "")
+                'picture': user_data["USER"].get("USER_PICTURE", ""),
+                'license_token': user_data["USER"]["OPTIONS"]["license_token"],
+                'can_stream_hq': user_data["USER"]["OPTIONS"]["web_hq"] or user_data["USER"]["OPTIONS"]["mobile_hq"],
+                'can_stream_lossless': user_data["USER"]["OPTIONS"]["web_lossless"] or user_data["USER"]["OPTIONS"]["mobile_lossless"]
             })
 
     def change_account(self, child_n):
-        if len(self.childs)-1 >= child_n:
-            self.current_user =self.childs[child_n]
-            self.selected_account = child_n
-        else:
-            self.current_user = self.childs[0]
-            self.selected_account = 0
+        if len(self.childs)-1 < child_n: child_n = 0
+        self.current_user = self.childs[child_n]
+        self.selected_account = child_n
+
         return (self.current_user, self.selected_account)
+
+    def get_track_url(self, track_token, track_format):
+        return self.get_tracks_url([track_token, ], track_format)
+
+    def get_tracks_url(self, track_tokens, track_format):
+        if not isinstance(track_tokens, list):
+            track_tokens = [track_tokens, ]
+        if not self.current_user['license_token']:
+            return []
+
+        try:
+            request = self.session.post(
+                "https://media.deezer.com/v1/get_url",
+                json={
+                    'license_token': self.current_user['license_token'],
+                    'media': [{
+                        'type': "FULL",
+                        'formats': [
+                            { 'cipher': "BF_CBC_STRIPE", 'format': track_format }
+                        ]
+                    }],
+                    'track_tokens': track_tokens
+                },
+                headers = self.http_headers
+            )
+            request.raise_for_status()
+            response = request.json()
+        except requests.exceptions.HTTPError:
+            return None
+
+        if response.get('data') and response['data'][0].get('media'):
+            return response['data'][0]['media'][0]['sources'][0]['url']
+        return None
